pub struct ProjectPathParams {
pub project_path: Option<String>,
}Fields
project_path: Option<String>Trait Implementations
Sourceimpl Debug for ProjectPathParams
impl Debug for ProjectPathParams
Sourceimpl<'de> Deserialize<'de> for ProjectPathParams
impl<'de> Deserialize<'de> for ProjectPathParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProjectPathParams
impl JsonSchema for ProjectPathParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProjectPathParams
impl RefUnwindSafe for ProjectPathParams
impl Send for ProjectPathParams
impl Sync for ProjectPathParams
impl Unpin for ProjectPathParams
impl UnsafeUnpin for ProjectPathParams
impl UnwindSafe for ProjectPathParams